#[repr(u8)]pub enum Cc {
CLOCK_ON_CHARACTER = 0,
CONTINOUS_CLOCK = 1,
}Variants
CLOCK_ON_CHARACTER = 0
Clock on character. In synchronous mode, SCLK cycles only when characters are being sent on Un_TXD or to complete a character that is being received.
CONTINOUS_CLOCK = 1
Continuous clock. SCLK runs continuously in synchronous mode, allowing characters to be received on Un_RxD independently from transmission on Un_TXD).
Implementations