#[repr(u8)]pub enum Clkpol {
FALLING_EDGE = 0,
RISING_EDGE = 1,
}Variants
FALLING_EDGE = 0
Falling edge. Un_RXD is sampled on the falling edge of SCLK.
RISING_EDGE = 1
Rising edge. Un_RXD is sampled on the rising edge of SCLK.
Implementations