nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Loop

Enum Loop 

#[repr(u8)]
pub enum Loop { NORMAL = 0, LOOPBACK = 1, }

Variants



NORMAL = 0

Normal operation.



LOOPBACK = 1

Loopback mode. This provides a mechanism to perform diagnostic loopback testing for USART data. Serial data from the transmitter (Un_TXD) is connected internally to serial input of the receive (Un_RXD). Un_TXD and Un_RTS activity will also appear on external pins if these functions are configured to appear on device pins. The receiver RTS signal is also looped back to CTS and performs flow control if enabled by CTSEN.

Implementations

Source

impl Loop

pub const fn from_bits(val: u8) -> Loop

pub const fn to_bits(self) -> u8