#[repr(u8)]pub enum Paritysel {
NO_PARITY = 0,
_RESERVED_1 = 1,
EVEN_PARITY = 2,
ODD_PARITY = 3,
}Variants
NO_PARITY = 0
No parity.
_RESERVED_1 = 1
EVEN_PARITY = 2
Even parity. Adds a bit to each character such that the number of 1s in a transmitted character is even, and the number of 1s in a received character is expected to be even.
ODD_PARITY = 3
Odd parity. Adds a bit to each character such that the number of 1s in a transmitted character is odd, and the number of 1s in a received character is expected to be odd.
Implementations