nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Rxpol

Enum Rxpol 

#[repr(u8)]
pub enum Rxpol { STANDARD = 0, INVERTED = 1, }

Variants



STANDARD = 0

Standard. The RX signal is used as it arrives from the pin. This means that the RX rest value is 1, start bit is 0, data is not inverted, and the stop bit is 1.



INVERTED = 1

Inverted. The RX signal is inverted before being used by the USART. This means that the RX rest value is 0, start bit is 1, data is inverted, and the stop bit is 0.

Implementations

Source

impl Rxpol

pub const fn from_bits(val: u8) -> Rxpol

pub const fn to_bits(self) -> u8