nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Txdis

Enum Txdis 

#[repr(u8)]
pub enum Txdis { ENABLED = 0, DISABLED = 1, }

Variants



ENABLED = 0

Not disabled. USART transmitter is not disabled.



DISABLED = 1

Disabled. USART transmitter is disabled after any character currently being transmitted is complete. This feature can be used to facilitate software flow control.

Implementations

Source

impl Txdis

pub const fn from_bits(val: u8) -> Txdis

pub const fn to_bits(self) -> u8